import { randomUUID } from "crypto";

jest.mock("typeorm");

describe("src/db:dataSource", () => {    
    beforeEach(() => {
        jest.resetModules();
        jest.clearAllMocks();

        process.env["DB_HOST"] = randomUUID();
        process.env["DB_USER"] = randomUUID();
        process.env["DB_PASS"] = randomUUID();
        process.env["DB_NAME"] = randomUUID();
    });

    it("throws an error if an environment variable is missing", async () => {
        delete process.env["DB_HOST"];
        process.env["DB_USER"] = randomUUID();
        process.env["DB_PASS"] = randomUUID();
        process.env["DB_NAME"] = randomUUID();

        await expect(async () => await import("./dataSource")).rejects.toThrowError(ReferenceError);

        jest.resetModules();

        process.env["DB_HOST"] = randomUUID();
        delete process.env["DB_USER"];

        await expect(async () => await import("./dataSource")).rejects.toThrowError(ReferenceError);

        jest.resetModules();

        process.env["DB_USER"] = randomUUID();
        delete process.env["DB_PASS"];

        await expect(async () => await import("./dataSource")).rejects.toThrowError(ReferenceError);

        jest.resetModules();

        process.env["DB_PASS"] = randomUUID();
        delete process.env["DB_NAME"];

        await expect(async () => await import("./dataSource")).rejects.toThrowError(ReferenceError);

        jest.resetModules();

        process.env["DB_NAME"] = randomUUID();

        expect(async () => await import("./dataSource")).not.toThrow();
    });

    it("exports an initialized dataSource", async () => {
        const dut = (await import("./dataSource")).default;

        expect(dut.initialize).toHaveBeenCalled();
    });
});