import path from "path";
import { DataSource } from "typeorm";
import { config } from "dotenv";
import dotenvExpand from "dotenv-expand";

const env = config();
dotenvExpand.expand(env);

const host = process.env["DB_HOST"];
const username = process.env["DB_USER"];
const password = process.env["DB_PASS"];
const database = process.env["DB_NAME"];

if (!host) throw new ReferenceError("Environment variable DB_HOST is missing");
if (!password) throw new ReferenceError("Environment variable DB_PASS is missing");
if (!username) throw new ReferenceError("Environment variable DB_USER is missing");
if (!database) throw new ReferenceError("Environment variable DB_NAME is missing");

const dataSource = new DataSource({
    type: "postgres",
    host: host,
    port: 5432,
    username: username,
    password: password,
    database: database,
    migrationsRun: true,
    migrations: [path.join(__dirname, "/migrations/*")],
    entities: [],
    migrationsTransactionMode: "each",
});

const initPromise = dataSource.initialize();

export default dataSource;
export {
    initPromise
}
